@@ -530,7 +530,7 @@ def compute_markers(tops, df_aligned_depths, consensus, depth_column):
     # Finding the consensus marker for each well
     markers = pd.DataFrame({"hole_id": [], "from": [], "to": [], "code": []})
     for key, group in df_aligned_depths.groupby("hole_id"):
-        tops_current = group.loc[aligned_positions].copy().reset_index(drop=True)
+        tops_current = group.iloc[aligned_positions].copy().reset_index(drop=True)
         if tops_current.shape[0] == 0:
             continue
         tops_current.index.rename("code", inplace=True)
